Cheetah.DummyTransaction module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.DummyTransaction module

Provides dummy Transaction and Response classes is used by Cheetah in place of real Webware transactions when the Template obj is not used directly as a Webware servlet.

Warning: This may be deprecated in the future, please do not rely on any specific DummyTransaction or DummyResponse behavior

class `Cheetah.DummyTransaction.` `DummyResponse`

  Bases: `object`

  A dummy Response class is used by Cheetah in place of real Webware Response objects when the Template obj is not used directly as a Webware servlet

  `flush`()
  `getvalue`(outputChunks=None)
  `safeConvert`(chunk)
  `write`(value)
  `writelines`(*lines)
  `writeln`(txt)

exception `Cheetah.DummyTransaction.` `DummyResponseFailure`

  Bases: `Exception`

class `Cheetah.DummyTransaction.` `DummyTransaction`(*args, **kwargs)

  Bases: `object`

  A dummy Transaction class is used by Cheetah in place of real Webware transactions when the Template obj is not used directly as a Webware servlet.

  It only provides a response object and method. All other methods and attributes make no sense in this context.

  `response`(resp=None)

class `Cheetah.DummyTransaction.` `TransformerResponse`(*args, **kwargs)

  Bases: `Cheetah.DummyTransaction.DummyResponse`

  `getvalue`(**kwargs)

class `Cheetah.DummyTransaction.` `TransformerTransaction`(*args, **kwargs)

  Bases: `object`

  `response`()